@@ -4,6 +4,7 @@ from explainaboard.loaders import (
     extractive_qa,
     file_loader,
     kg_link_tail_prediction,
+    language_modeling,
     loader,
     loader_registry,
     named_entity_recognition,
@@ -22,6 +23,7 @@ __all__ = [
     'conditional_generation',
     'extractive_qa',
     'kg_link_tail_prediction',
+    'language_modeling',
     'loader',
     'named_entity_recognition',
     'qa_multiple_choice',
