@@ -326,7 +326,6 @@ class F1Score(Metric):
         if agg_stats.size == 1:
             return float(agg_stats)
 
-        # print(agg_stats)
         config = cast(F1ScoreConfig, self._get_config(config))
         supported_averages = {'micro', 'macro'}
         stat_mult: int = 4 if config.separate_match else 3
@@ -781,6 +780,54 @@ class F1ScoreQA(QAMetric):
         return f1
 
 
+@dataclass
+class LogProbConfig(MetricConfig):
+    # If false, return log probability, if true return perplexity
+    ppl: bool = False
+
+    def to_metric(self):
+        return LogProb(self)
+
+
+class LogProb(Metric):
+    """
+    Calculate the log probability
+    """
+
+    def calc_stats_from_data(
+        self, true_data: list, pred_data: list, config: Optional[MetricConfig] = None
+    ) -> MetricStats:
+        """
+        Take in a list of floats (token-level), or list of lists of floats (sentence
+        level) and either one float for each or float+length rows
+        """
+        if len(pred_data) == 0 or isinstance(pred_data[0], float):
+            return MetricStats(np.array(pred_data))
+        elif isinstance(pred_data[0], list):
+            return MetricStats(np.array([[sum(x), len(x)] for x in pred_data]))
+        else:
+            t = type(pred_data[0])
+            raise ValueError(f'Invalid type of pred_data for calc_stats_from_data {t}')
+
+    def calc_metric_from_aggregate(
+        self, agg_stats: np.ndarray, config: Optional[MetricConfig] = None
+    ) -> float:
+        """From aggregated sufficient statistics, calculate the metric value
+        :param agg_stats: aggregated statistics
+        :param config: a configuration to over-ride the default for this object
+        :return: a single scalar metric value
+        """
+        config = cast(LogProbConfig, self._get_config(config))
+        val = (
+            float(agg_stats)
+            if (isinstance(agg_stats, float) or agg_stats.size == 1)
+            else agg_stats[0] / agg_stats[1]
+        )
+        if config.ppl:
+            val = np.exp(-val)
+        return val
+
+
 def metric_name_to_config(name: str) -> MetricConfig:
     try:
         metric_module = sys.modules[__name__]
