@@ -4,12 +4,14 @@ from explainaboard.processors import (
     conditional_generation,
     extractive_qa,
     kg_link_tail_prediction,
+    language_modeling,
     machine_translation,
     named_entity_recognition,
     qa_multiple_choice,
     summarization,
     text_classification,
     text_pair_classification,
+    word_segmentation,
 )
 from explainaboard.processors.processor_registry import get_processor
 
@@ -19,10 +21,12 @@ __all__ = [
     'extractive_qa',
     'get_processor',
     'kg_link_tail_prediction',
+    'language_modeling',
     'machine_translation',
     'named_entity_recognition',
     'qa_multiple_choice',
     'summarization',
     'text_classification',
     'text_pair_classification',
+    "word_segmentation",
 ]
