@@ -1,23 +1,28 @@
 from __future__ import annotations
 
+from collections.abc import Iterator
 from functools import lru_cache
 
+from datalabs import aggregating
 from datalabs.operations.featurize.plugins.summarization.sum_attribute import (
     SUMAttribute,
 )
 from datalabs.operations.featurize.summarization import get_oracle_summary
 import numpy
 
-from explainaboard import feature
+from explainaboard import feature, TaskType
 from explainaboard.info import SysOutputInfo
+from explainaboard.metric import EaaSMetricConfig, MetricConfig
 from explainaboard.processors.conditional_generation import (
     ConditionalGenerationProcessor,
 )
 from explainaboard.processors.processor_registry import register_processor
-from explainaboard.tasks import TaskType
+import explainaboard.utils.feature_funcs
 from explainaboard.utils.py_utils import hash_dict
 
 # to calculate advanced features
+from explainaboard.utils.tokenizer import Tokenizer
+
 summary_attribute = SUMAttribute()
 
 
@@ -128,8 +133,12 @@ class SummarizationProcessor(ConditionalGenerationProcessor):
         return f
 
     @classmethod
-    def default_metrics(cls) -> list[str]:
-        return ["rouge1", "rouge2", "rougeL"]
+    def default_metrics(cls, language=None) -> list[MetricConfig]:
+        return [
+            EaaSMetricConfig(name='rouge1', language=language),
+            EaaSMetricConfig(name='rouge2', language=language),
+            EaaSMetricConfig(name='rougeL', language=language),
+        ]
 
     def _get_oracle_position(self, sys_info: SysOutputInfo, existing_features: dict):
         return get_oracle(existing_features)["oracle_position"]
@@ -160,3 +169,9 @@ class SummarizationProcessor(ConditionalGenerationProcessor):
             existing_features["source"], existing_features["reference"]
         )
         return res["attr_novelty"]
+
+    @aggregating()
+    def _statistics_func(self, samples: Iterator, tokenizer: Tokenizer):
+        return explainaboard.utils.feature_funcs.accumulate_vocab_from_samples(
+            samples, lambda x: x['summary'], tokenizer
+        )
